pub struct FileClock { /* private fields */ }Expand description
File-backed clock used by integration tests that run the daemon as a child process. Advancing the integer timestamp in the file wakes pending timers.
Implementations