next_id

Function next_id 

pub fn next_id<'a>(
    prefix: &str,
    existing: impl IntoIterator<Item = &'a str>,
) -> Result<String, IdError>
Allocates one greater than the greatest positive numeric suffix for the active prefix. IDs for other prefixes and malformed suffixes do not count.