pub fn read_agent_output(path: &Path) -> Result<AgentOutput>Expand description
Reassembles each agent stream from every complete captured record. Test and merge output is deliberately excluded from vendor classification.
pub fn read_agent_output(path: &Path) -> Result<AgentOutput>Reassembles each agent stream from every complete captured record. Test and merge output is deliberately excluded from vendor classification.