pub enum ExitClaim {
Claimed,
AlreadyClaimed {
state: String,
},
}Expand description
Whether the caller won the running to driving transition and with it
ownership of the agent’s exit evidence and of the rest of the walk.
Variants