Module clock

Module clock 

Structs

FileClock
File-backed clock used by integration tests that run the daemon as a child process. Advancing the integer timestamp in the file wakes pending timers.
SystemClock

Traits

Clock

Functions

format_timestamp