Module clock
sloop
0.1.0
Module clock
Module Items
Structs
Traits
Functions
In crate sloop
sloop
Module
clock
Structs

File
Clock
File-backed clock used by integration tests that run the daemon as a child process. Advancing the integer timestamp in the file wakes pending timers.
System
Clock
Traits

Clock
Functions

format_
timestamp