pub fn display_state<'a>(state: &'a str, reason: Option<&Ineligible>) -> &'a strExpand description
Blocked is derived from dependency state rather than persisted on the ticket, so display state changes as soon as the last blocker merges.
pub fn display_state<'a>(state: &'a str, reason: Option<&Ineligible>) -> &'a strBlocked is derived from dependency state rather than persisted on the ticket, so display state changes as soon as the last blocker merges.