Module ids

Module ids 

Enums

IdError

Constants

DEFAULT_PROJECT_PREFIX
DEFAULT_TICKET_PREFIX

Functions

next_id
Allocates one greater than the greatest positive numeric suffix for the active prefix. IDs for other prefixes and malformed suffixes do not count.
valid_prefix
Prefixes stay safe as unquoted frontmatter scalars while still allowing readable multi-part names such as MY-WORK.