pub fn output_staleness(
path: &Path,
started_at_ms: i64,
now_ms: i64,
report_after_ms: i64,
) -> Result<OutputStaleness>Expand description
Measures agent-output silence from the last complete record, falling back to the durable stage start when the agent has not written anything yet.